@@ -1,16 +1,17 @@
 # Traffic Monitor Detector Raw Data (TMD_I480)
 # modify from TMD
-# ver:0.1.0
-# 2021/09/16
+#
+#
 # parsing Traffic Monitor Detector
 # hardware:(Batman-201/601): ISK IWR6843/1843
 # company: Joybien Technologies: www.joybien.com
 # author: Zach Chen
+# ver:0.1.1 2021/09/16
+# ver:2.0.1 2022/04/28
 #===========================================
 # output: V6,V7,V8,v9 Raw data
 
 
-
 import serial
 import time
 import struct
@@ -35,21 +36,21 @@ class header:
 
 class TrafficMD_I480:
 	
-	magicWord =  [b'\x02',b'\x01',b'\x04',b'\x03',b'\x06',b'\x05',b'\x08',b'\x07',b'\0x99']
+	magicWord =  [b'\x01',b'\x02',b'\x03',b'\x04',b'\x05',b'\x06',b'\x07',b'\x08',b'\0x99']
 	port = ""
 	hdr = header
 
 	# provide csv file dataframe
 	# real-time 
 	v6_col_names_rt = ['fN','type','range','azimuth','elv' ,'doppler','sx', 'sy', 'sz'] #ok
-	v7_col_names_rt = ['fN','type','posX','posY','velX','velY','accX','accY','posZ','velZ','accZ','tid']
+	v7_col_names_rt = ['fN','type','posX','posY','posZ','velX','velY','velZ','accX','accY','accZ','tid']
 	v8_col_names_rt = ['fN','type','targetID']
 	v9_col_names_rt = ['fN','type','snr','noise']
 	
 	# read from file for trace point clouds
 	fileName = ''
 	v6_col_names = ['time','fN','type','range','azimuth','elv' ,'doppler','sx', 'sy', 'sz']
-	v7_col_names = ['time','fN','type','posX','posY','velX','velY','accX','accY','posZ','velZ','accZ','tid']
+	v7_col_names = ['time','fN','type','posX','posY','posZ','velX','velY','velZ','accX','accY','accZ','tid']
 	v8_col_names = ['time','fN','type','targetID']
 	v9_col_names = ['fN','type','snr','noise']
 	sim_startFN = 0
@@ -71,7 +72,7 @@ class TrafficMD_I480:
 	def __init__(self,port):
 		self.port = port
 		print("(jb)Traffic Monitor Detector(TMD_I480) raw Data lib initial")
-		print("(jb)For Hardware:Batman-201/501(ISK)")
+		print("(jb)For Hardware:Batman-201/501/601(ISK)")
 		print("(jb)Version: v0.1.0")
 		print("(jb)Hardware: IWR-6843/1843")
 		print("(jb)Firmware: TMD")
@@ -424,7 +425,7 @@ class TrafficMD_I480:
 						(tid,posX,posY,posZ,velX,velY,velZ,accX,accY,accZ,ec0,ec1,ec2,ec3,ec4,ec5,ec6,ec7,ec8,ec9,ec10,ec11,ec12,ec13,ec14,ec15,g,conf) = struct.unpack('I27f', sbuf) 
 						#fieldNames = ['time','frameNum','type','range/px','azimuth/py','elv/vx','doppler/vy','sx/accX','sy/accY','sz/pz','na/vz','na/accZ','na/ID']
 						if (df == 'DataFrame' ):
-							v7df.append((self.hdr.frameNumber,'v7',posX,posY,velX,velY,accX,accY,posZ,velZ,accZ,tid))
+							v7df.append((self.hdr.frameNumber,'v7',posX,posY,posZ,velX,velY,velZ,accX,accY,accZ,tid))
 						else:
 							v7.append((tid,posX,posY,posZ,velX,velY,velZ,accX,accY,accZ))
 							#print("tid = ({:d}) ,posX:{:.4f} posY:{:.4f} posZ:{:.4f}".format(tid,posX,posY,posZ))
